Lock Rest API — Rucio 1.2 documentation

# Lock Rest API

Overview

Resource | Operation | Description
--- | --- | ---
| GET /locks/(scope)/(name) |
| GET /locks/(rse) |

Details

`GET` `/locks/`(scope)`/`(name)

  REST APIs for dataset locks.

`GET` `/locks/`(rse)

  get locks for a given rse.

  Parameters: | rse – The RSE name.
  Query Parameters:
  | did_type – The type used to filter, e.g., DATASET, CONTAINER.
  Response Headers:
  | Content-Type – application/x-json-stream
  Status Codes: | 200 OK – OK. 401 Unauthorized – Invalid Auth Token. 500 Internal Server Error – Internal Error.
  Returns: | Line separated list of dictionaries with lock information.